import request from '@/utils/request'

// 初始化合同
export function initContract() {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '采购管理_采购请款表_查询数据'
    }
  })
}
// 查询表1
export function searchTable1(...params) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '采购管理_采购请款表_查询数据',
      param: '采购合同流水号_check=' + params[2] + '&采购合同流水号=' + params[3] + '&供应商名称_check=' + params[4] + '&供应商名称=' + params[5],
      Pagination: params[0] + '&' + params[1]
    }
  })
}
// 查询表01付款计划
export function searchTable01(...params) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '采购管理_付款计划_查询数据',
      param: '采购合同流水号_check=1&采购合同流水号=' + params[0]
    }
  })
}
// 增加表01付款计划
export function addTable01(...params) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '采购管理_付款计划_增加数据',
      param: `采购合同流水号=${params[0]}&计划付款日期=${params[1]}&计划付款金额=${params[2]}&计划付款备注=${params[3]}`
    }
  })
}
// 删除表01付款计划
export function deleteTable01(...params) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '2',
      name: '采购管理_付款计划_删除数据',
      param: `付款计划流水号=${params[0]}`
    }
  })
}
// 采购合同内容查询
export function searchTable2(num) {
  return request({
    url: '',
    method: 'post',
    data: {
      type: '1',
      name: '采购管理_采购合同内容_查询数据',
      param: '采购合同流水号=' + num
    }
  })
}
